@@ -7,6 +7,11 @@
 #	Author: Chui Tey <teyc@bigfoot.com>
 #
 #	Change History:
+#       0.6.2
+#
+#       1 Dec 2001     Bug fix: getData renders on Netscape now
+#                      Fabio Forno provided HILOCLOSE methods in _chartdata
+#
 #	0.6.1
 #
 #       3  Nov 2001     Dirk Datzert <dirk.datzert@rasselstein-hoesch.de>
@@ -735,9 +740,6 @@ class ZGDChart(
 		"""
 		return self._chart(GDC_3DPIE, RESPONSE)
 
-	#	XXX To do: Hack chartdata to
-	#	           handle hi lo close charts
-	#
 	def Hi_Lo_Close_2D(self, REQUEST=None, RESPONSE=None):
 		"""
 		Renders dataset as a hi lo close chart
@@ -805,7 +807,7 @@ class ZGDChart(
 		"""
 		Renders dataset in the format requested
 		"""
-		self.REQUEST['zgdchart_runtime_type'] = GDC_TYPE
+		self.REQUEST[self.runtime_prefix + 'type'] = GDC_TYPE
 
 		# 
 		# Two methods are available for 
@@ -830,12 +832,7 @@ class ZGDChart(
 			apply(chart, (GDC_TYPE, (self.width, self.height), tempfile) + tuple(chartdata))
 			if RESPONSE: RESPONSE['content-type']=self.content_type
 			output = tempfile.getvalue()
-			#
-			# requires GDChart 0.3
-			# apply(chart, (GDC_TYPE, (self.width, self.height), self.tempfile) + tuple(chartdata))
-			# if RESPONSE: RESPONSE['content-type']=self.content_type
-			# output = open(self.tempfile,'rb').read()
-			#
+
 		finally:
 			_chart_lock.release()			
 		return  output
@@ -932,11 +929,6 @@ class ZGDChart(
 		for s in params.keys():
 			eval("option(%s = params['%s'])" % (s,s))
 
-	# 
-	# I thought Andreas interpretation <andreas.furbach@eds.com> 
-	# is rather 'cleaner', so we'll use his _chartdata instead
-	# if this breaks your old code, reinstate _chartdata_old
-	#	
 	def _chartdata(self, rows):
                 """
                 return the first and second columns of sql query
@@ -944,6 +936,8 @@ class ZGDChart(
                 """
                 # rows = getattr(self, self.SQL)()
                 # data[0] is list of labels
+                zgdchart_runtime_type=self.REQUEST[self.runtime_prefix+'type'] 
+                print "chartdata type: " , zgdchart_runtime_type
                 data =  []
                 start = 0
                 for row in rows:
@@ -959,8 +953,8 @@ class ZGDChart(
                         # Pie Chart only makes sense with 1 data column
                         #
                         for i in range(len(row)):
-                            if (self.REQUEST['zgdchart_runtime_type'] != GDC_3DPIE \
-                               and self.REQUEST['zgdchart_runtime_type'] != GDC_2DPIE) \
+                            if (zgdchart_runtime_type!= GDC_3DPIE \
+                               and zgdchart_runtime_type != GDC_2DPIE) \
                                or row[1] != 0:
                               #
                               # Coerce the first field into a string
@@ -970,58 +964,34 @@ class ZGDChart(
                                   data[i].append( str  (row[i]))
                               else:
                                   data[i].append( float(row[i]))
+
+                # Fabio Forno's patch for handling HILOCLOSE types
                 #
-                # convert lists to tuples
-                # apparently, gdchart.chart() accepts lists
-                # as well, but I better check with
-                # M Steed first.
-                #
-                # I just tried.
+                if zgdchart_runtime_type in \
+                    (GDC_3DHILOCLOSE,     \
+                     GDC_HILOCLOSE,       \
+                     GDC_3DCOMBO_HLC_AREA,\
+                     GDC_3DCOMBO_HLC_BAR, \
+                     GDC_COMBO_HLC_AREA,  \
+                     GDC_COMBO_HLC_BAR) and len(data) >=4:
+                     #
+                     # Hi-Lo-Close format 
+                     # [labels], ([hi],[lo],[close]), [combo]
+                     #
+                     _data=[]
+                     _data.append(data[0])           # copy labels
+                     _data.append(tuple(data[1:4]))  # hi-lo-close
+                     if len(data) >= 5 and        \
+                        zgdchart_runtime_type in  \
+                           (GDC_3DCOMBO_HLC_AREA, \
+                            GDC_3DCOMBO_HLC_BAR,  \
+                            GDC_COMBO_HLC_AREA,   \
+                            GDC_COMBO_HLC_BAR):
+                                # use spare column for combos 
+                                _data.append (data[4])
+                     data = _data
                 return data
 
-	#------------------------------------------------------------	
-	# Deprecated in favour of Andreas's implementation
-	#
-	def _chartdata_old(self):
-		"""
-		return the first and second columns of sql query
-		results as a pair of tuples
-		"""
-		rows = getattr(self, self.SQL)()
-		#
-		# have a peek and see how many fields per row
-		#
-		labels= []
-		data =  []
-		if len(rows):
-			num_fields = len(rows[0])
-			for i in range(num_fields-1):
-				data.append([])
-
-		for row in rows:
-			# each row is a list of fields
-			fields = row
-			#
-			# Only insert rows with zero values if
-			# it is not a pie chart
-			#
-			if (self.REQUEST['zgdchart_runtime_type'] != GDC_3DPIE and
-				self.REQUEST['zgdchart_runtime_type'] != GDC_2DPIE) or float(fields[1])>0:
-				#
-				#	Coerce the first field into a string
-				#	and second field into a float
-				#
-				labels.append( str  (fields[0]))
-				for i in range(num_fields - 1):
-					data[i].append(  float (fields[i+1]))
-		#
-		# convert lists to tuples
-		# apparently, gdchart.chart() accepts lists
-		# as well, but I better check with
-		# M Steed first.
-		#
-		return tuple( map(tuple, [labels] + data ))
-
 	def _chartdata_SQL(self):
 		SQL = getattr(self, self.SQL)
 		rows = SQL()
